@@ -11,16 +11,18 @@ use constant EVALTEXT   => 6;
 use constant IS_REQUIRE => 7;
 use constant HINTS      => 8;
 use constant BITMASK    => 9;
-use Text::Template::Simple::Util qw( ishref fatal );
 
-$VERSION = '0.79_09';
+use Carp qw( croak );
+
+$VERSION = '0.50';
 
 sub stack {
    my $self    = shift;
    my $opt     = shift || {};
-   fatal('tts.caller.stack.hash') if ! ishref($opt);
-   my $frame   = $opt->{frame} || 0;
-   my $type    = $opt->{type}  || '';
+   die "Parameters to stack() must be a HASH" if ref($opt) ne 'HASH';
+   my $frame   = $opt->{frame};
+   my $type    = $opt->{type} || '';
+      $frame ||= 0;
    my(@callers, $context);
 
    TRACE: while ( my @c = caller ++$frame ) {
@@ -57,7 +59,7 @@ sub stack {
       return $self->$method( $opt, \@callers );
    }
 
-   fatal('tts.caller.stack.type', $type);
+   croak "Unknown caller stack type: $type";
 }
 
 sub _string {
@@ -140,7 +142,7 @@ sub _text_table {
    my $opt     = shift;
    my $callers = shift;
    eval { require Text::Table; };
-   fatal('tts.caller._text_table.module', $@) if $@;
+   croak "Caller stack type 'text_table' requires Text::Table" if $@;
 
    my $table = Text::Table->new( qw(
                   | CONTEXT    | SUB      | LINE  | FILE    | HASARGS
@@ -184,7 +186,7 @@ __END__
 
 =head1 NAME
 
-Text::Template::Simple::Caller - Caller stack tracer
+Text::Template::Simple::Caller - Caller stack tracer for Text::Template::Simple
 
 =head1 SYNOPSIS
 
@@ -197,13 +199,6 @@ Text::Template::Simple::Caller - Caller stack tracer
 
 =head1 DESCRIPTION
 
-This document describes version C<0.79_09> of C<Text::Template::Simple::Caller>
-released on C<7 August 2009>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
-
 Caller stack tracer for Text::Template::Simple. This module is not used
 directly inside templates. You must use the global template function
 instead. See L<Text::Template::Simple::Dummy> for usage from the templates.
@@ -248,16 +243,16 @@ Uses the optional module C<Text::Table> to format the dump.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2009 Burak Gursoy. All rights reserved.
+Copyright 2004-2008 Burak GE<252>rsoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.8.8 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
