@@ -8,14 +8,12 @@ package Text::Template::Simple::Dummy;
 use strict;
 use vars qw($VERSION);
 use Text::Template::Simple::Caller;
-use Text::Template::Simple::Util qw();
 
-$VERSION = '0.79_09';
+$VERSION = '0.50';
 
 sub stack { # just a wrapper
    my $opt = shift || {};
-   Text::Template::Simple::Util::fatal('tts.caller.stack.hash')
-      if ! Text::Template::Simple::Util::ishref($opt);
+   die "Parameters to stack() must be a HASH" if ref($opt) ne 'HASH';
    $opt->{frame} = 1;
    Text::Template::Simple::Caller->stack( $opt );
 }
@@ -26,7 +24,7 @@ __END__
 
 =head1 NAME
 
-Text::Template::Simple::Dummy - Container class
+Text::Template::Simple::Dummy - Container class for Text::Template::Simple
 
 =head1 SYNOPSIS
 
@@ -34,13 +32,6 @@ TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.79_09> of C<Text::Template::Simple::Dummy>
-released on C<7 August 2009>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
-
 All templates are compiled into this class.
 
 =head1 FUNCTIONS
@@ -63,16 +54,16 @@ See L<Text::Template::Simple::Caller> for more information.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2009 Burak Gursoy. All rights reserved.
+Copyright 2004-2008 Burak GE<252>rsoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.8.8 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
